@@ -119,20 +119,20 @@ class Library(GObject):
         conn = sqlite3.connect(db_file)
         cursor = conn.cursor()
 
-        act_files = self._get_files(folder)
+        disc_files = self._get_files(folder)
         db_files = cursor.execute("SELECT uri FROM songs").fetchall()
         
-        updated = len(act_files) != len(db_files)
+        updated = len(disc_files) != len(db_files)
         
         for uri, in db_files:
             try:
-                act_files.remove(str(uri))   # convert unicode
+                disc_files.remove(str(uri))   # convert unicode
             except ValueError:
                  cursor.execute("DELETE FROM songs WHERE uri = ?", (uri,))
                  print "Removed: %s" % uri
 
         # add new files
-        for uri in act_files:
+        for uri in disc_files:
             song = {"title": "None", "artist": "None", "album": "None", "genre": "None", "tracknumber": 0}
                             
             path = gst.uri_get_location(uri)
